package com.mysql.jdbc;

import java.sql.SQLException;
import java.sql.Time;
import java.sql.Timestamp;
import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.Map;
import java.util.TimeZone;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/TimeUtil.class */
public class TimeUtil {
    static final Map ABBREVIATED_TIMEZONES;
    static final TimeZone GMT_TIMEZONE = TimeZone.getTimeZone("GMT");
    static final Map TIMEZONE_MAPPINGS;

    static {
        HashMap tempMap = new HashMap();
        tempMap.put("Romance", "Europe/Paris");
        tempMap.put("Romance Standard Time", "Europe/Paris");
        tempMap.put("Warsaw", "Europe/Warsaw");
        tempMap.put("Central Europe", "Europe/Prague");
        tempMap.put("Central Europe Standard Time", "Europe/Prague");
        tempMap.put("Prague Bratislava", "Europe/Prague");
        tempMap.put("W. Central Africa Standard Time", "Africa/Luanda");
        tempMap.put("FLE", "Europe/Helsinki");
        tempMap.put("FLE Standard Time", "Europe/Helsinki");
        tempMap.put("GFT", "Europe/Athens");
        tempMap.put("GFT Standard Time", "Europe/Athens");
        tempMap.put("GTB", "Europe/Athens");
        tempMap.put("GTB Standard Time", "Europe/Athens");
        tempMap.put("Israel", "Asia/Jerusalem");
        tempMap.put("Israel Standard Time", "Asia/Jerusalem");
        tempMap.put("Arab", "Asia/Riyadh");
        tempMap.put("Arab Standard Time", "Asia/Riyadh");
        tempMap.put("Arabic Standard Time", "Asia/Baghdad");
        tempMap.put("E. Africa", "Africa/Nairobi");
        tempMap.put("E. Africa Standard Time", "Africa/Nairobi");
        tempMap.put("Saudi Arabia", "Asia/Riyadh");
        tempMap.put("Saudi Arabia Standard Time", "Asia/Riyadh");
        tempMap.put("Iran", "Asia/Tehran");
        tempMap.put("Iran Standard Time", "Asia/Tehran");
        tempMap.put("Afghanistan", "Asia/Kabul");
        tempMap.put("Afghanistan Standard Time", "Asia/Kabul");
        tempMap.put("India", "Asia/Calcutta");
        tempMap.put("India Standard Time", "Asia/Calcutta");
        tempMap.put("Myanmar Standard Time", "Asia/Rangoon");
        tempMap.put("Nepal Standard Time", "Asia/Katmandu");
        tempMap.put("Sri Lanka", "Asia/Colombo");
        tempMap.put("Sri Lanka Standard Time", "Asia/Colombo");
        tempMap.put("Beijing", "Asia/Shanghai");
        tempMap.put("China", "Asia/Shanghai");
        tempMap.put("China Standard Time", "Asia/Shanghai");
        tempMap.put("AUS Central", "Australia/Darwin");
        tempMap.put("AUS Central Standard Time", "Australia/Darwin");
        tempMap.put("Cen. Australia", "Australia/Adelaide");
        tempMap.put("Cen. Australia Standard Time", "Australia/Adelaide");
        tempMap.put("Vladivostok", "Asia/Vladivostok");
        tempMap.put("Vladivostok Standard Time", "Asia/Vladivostok");
        tempMap.put("West Pacific", "Pacific/Guam");
        tempMap.put("West Pacific Standard Time", "Pacific/Guam");
        tempMap.put("E. South America", "America/Sao_Paulo");
        tempMap.put("E. South America Standard Time", "America/Sao_Paulo");
        tempMap.put("Greenland Standard Time", "America/Godthab");
        tempMap.put("Newfoundland", "America/St_Johns");
        tempMap.put("Newfoundland Standard Time", "America/St_Johns");
        tempMap.put("Pacific SA", "America/Caracas");
        tempMap.put("Pacific SA Standard Time", "America/Caracas");
        tempMap.put("SA Western", "America/Caracas");
        tempMap.put("SA Western Standard Time", "America/Caracas");
        tempMap.put("SA Pacific", "America/Bogota");
        tempMap.put("SA Pacific Standard Time", "America/Bogota");
        tempMap.put("US Eastern", "America/Indianapolis");
        tempMap.put("US Eastern Standard Time", "America/Indianapolis");
        tempMap.put("Central America Standard Time", "America/Regina");
        tempMap.put("Mexico", "America/Mexico_City");
        tempMap.put("Mexico Standard Time", "America/Mexico_City");
        tempMap.put("Canada Central", "America/Regina");
        tempMap.put("Canada Central Standard Time", "America/Regina");
        tempMap.put("US Mountain", "America/Phoenix");
        tempMap.put("US Mountain Standard Time", "America/Phoenix");
        tempMap.put("GMT", "Europe/London");
        tempMap.put("GMT Standard Time", "Europe/London");
        tempMap.put("Ekaterinburg", "Asia/Yekaterinburg");
        tempMap.put("Ekaterinburg Standard Time", "Asia/Yekaterinburg");
        tempMap.put("West Asia", "Asia/Karachi");
        tempMap.put("West Asia Standard Time", "Asia/Karachi");
        tempMap.put("Central Asia", "Asia/Dhaka");
        tempMap.put("Central Asia Standard Time", "Asia/Dhaka");
        tempMap.put("N. Central Asia Standard Time", "Asia/Novosibirsk");
        tempMap.put("Bangkok", "Asia/Bangkok");
        tempMap.put("Bangkok Standard Time", "Asia/Bangkok");
        tempMap.put("North Asia Standard Time", "Asia/Krasnoyarsk");
        tempMap.put("SE Asia", "Asia/Bangkok");
        tempMap.put("SE Asia Standard Time", "Asia/Bangkok");
        tempMap.put("North Asia East Standard Time", "Asia/Ulaanbaatar");
        tempMap.put("Singapore", "Asia/Singapore");
        tempMap.put("Singapore Standard Time", "Asia/Singapore");
        tempMap.put("Taipei", "Asia/Taipei");
        tempMap.put("Taipei Standard Time", "Asia/Taipei");
        tempMap.put("W. Australia", "Australia/Perth");
        tempMap.put("W. Australia Standard Time", "Australia/Perth");
        tempMap.put("Korea", "Asia/Seoul");
        tempMap.put("Korea Standard Time", "Asia/Seoul");
        tempMap.put("Tokyo", "Asia/Tokyo");
        tempMap.put("Tokyo Standard Time", "Asia/Tokyo");
        tempMap.put("Yakutsk", "Asia/Yakutsk");
        tempMap.put("Yakutsk Standard Time", "Asia/Yakutsk");
        tempMap.put("Central European", "Europe/Belgrade");
        tempMap.put("Central European Standard Time", "Europe/Belgrade");
        tempMap.put("W. Europe", "Europe/Berlin");
        tempMap.put("W. Europe Standard Time", "Europe/Berlin");
        tempMap.put("Tasmania", "Australia/Hobart");
        tempMap.put("Tasmania Standard Time", "Australia/Hobart");
        tempMap.put("AUS Eastern", "Australia/Sydney");
        tempMap.put("AUS Eastern Standard Time", "Australia/Sydney");
        tempMap.put("E. Australia", "Australia/Brisbane");
        tempMap.put("E. Australia Standard Time", "Australia/Brisbane");
        tempMap.put("Sydney Standard Time", "Australia/Sydney");
        tempMap.put("Central Pacific", "Pacific/Guadalcanal");
        tempMap.put("Central Pacific Standard Time", "Pacific/Guadalcanal");
        tempMap.put("Dateline", "Pacific/Majuro");
        tempMap.put("Dateline Standard Time", "Pacific/Majuro");
        tempMap.put("Fiji", "Pacific/Fiji");
        tempMap.put("Fiji Standard Time", "Pacific/Fiji");
        tempMap.put("Samoa", "Pacific/Apia");
        tempMap.put("Samoa Standard Time", "Pacific/Apia");
        tempMap.put("Hawaiian", "Pacific/Honolulu");
        tempMap.put("Hawaiian Standard Time", "Pacific/Honolulu");
        tempMap.put("Alaskan", "America/Anchorage");
        tempMap.put("Alaskan Standard Time", "America/Anchorage");
        tempMap.put("Pacific", "America/Los_Angeles");
        tempMap.put("Pacific Standard Time", "America/Los_Angeles");
        tempMap.put("Mexico Standard Time 2", "America/Chihuahua");
        tempMap.put("Mountain", "America/Denver");
        tempMap.put("Mountain Standard Time", "America/Denver");
        tempMap.put("Central", "America/Chicago");
        tempMap.put("Central Standard Time", "America/Chicago");
        tempMap.put("Eastern", "America/New_York");
        tempMap.put("Eastern Standard Time", "America/New_York");
        tempMap.put("E. Europe", "Europe/Bucharest");
        tempMap.put("E. Europe Standard Time", "Europe/Bucharest");
        tempMap.put("Egypt", "Africa/Cairo");
        tempMap.put("Egypt Standard Time", "Africa/Cairo");
        tempMap.put("South Africa", "Africa/Harare");
        tempMap.put("South Africa Standard Time", "Africa/Harare");
        tempMap.put("Atlantic", "America/Halifax");
        tempMap.put("Atlantic Standard Time", "America/Halifax");
        tempMap.put("SA Eastern", "America/Buenos_Aires");
        tempMap.put("SA Eastern Standard Time", "America/Buenos_Aires");
        tempMap.put("Mid-Atlantic", "Atlantic/South_Georgia");
        tempMap.put("Mid-Atlantic Standard Time", "Atlantic/South_Georgia");
        tempMap.put("Azores", "Atlantic/Azores");
        tempMap.put("Azores Standard Time", "Atlantic/Azores");
        tempMap.put("Cape Verde Standard Time", "Atlantic/Cape_Verde");
        tempMap.put("Russian", "Europe/Moscow");
        tempMap.put("Russian Standard Time", "Europe/Moscow");
        tempMap.put("New Zealand", "Pacific/Auckland");
        tempMap.put("New Zealand Standard Time", "Pacific/Auckland");
        tempMap.put("Tonga Standard Time", "Pacific/Tongatapu");
        tempMap.put("Arabian", "Asia/Muscat");
        tempMap.put("Arabian Standard Time", "Asia/Muscat");
        tempMap.put("Caucasus", "Asia/Tbilisi");
        tempMap.put("Caucasus Standard Time", "Asia/Tbilisi");
        tempMap.put("GMT Standard Time", "GMT");
        tempMap.put("Greenwich", "GMT");
        tempMap.put("Greenwich Standard Time", "GMT");
        tempMap.put("UTC", "GMT");
        TIMEZONE_MAPPINGS = Collections.unmodifiableMap(tempMap);
        HashMap tempMap2 = new HashMap();
        tempMap2.put("ACST", new String[]{"America/Porto_Acre"});
        tempMap2.put("ACT", new String[]{"America/Porto_Acre"});
        tempMap2.put("ADDT", new String[]{"America/Pangnirtung"});
        tempMap2.put("ADMT", new String[]{"Africa/Asmera", "Africa/Addis_Ababa"});
        tempMap2.put("ADT", new String[]{"Atlantic/Bermuda", "Asia/Baghdad", "America/Thule", "America/Goose_Bay", "America/Halifax", "America/Glace_Bay", "America/Pangnirtung", "America/Barbados", "America/Martinique"});
        tempMap2.put("AFT", new String[]{"Asia/Kabul"});
        tempMap2.put("AHDT", new String[]{"America/Anchorage"});
        tempMap2.put("AHST", new String[]{"America/Anchorage"});
        tempMap2.put("AHWT", new String[]{"America/Anchorage"});
        tempMap2.put("AKDT", new String[]{"America/Juneau", "America/Yakutat", "America/Anchorage", "America/Nome"});
        tempMap2.put("AKST", new String[]{"Asia/Aqtobe", "America/Juneau", "America/Yakutat", "America/Anchorage", "America/Nome"});
        tempMap2.put("AKT", new String[]{"Asia/Aqtobe"});
        tempMap2.put("AKTST", new String[]{"Asia/Aqtobe"});
        tempMap2.put("AKWT", new String[]{"America/Juneau", "America/Yakutat", "America/Anchorage", "America/Nome"});
        tempMap2.put("ALMST", new String[]{"Asia/Almaty"});
        tempMap2.put("ALMT", new String[]{"Asia/Almaty"});
        tempMap2.put("AMST", new String[]{"Asia/Yerevan", "America/Cuiaba", "America/Porto_Velho", "America/Boa_Vista", "America/Manaus"});
        tempMap2.put("AMT", new String[]{"Europe/Athens", "Europe/Amsterdam", "Asia/Yerevan", "Africa/Asmera", "America/Cuiaba", "America/Porto_Velho", "America/Boa_Vista", "America/Manaus", "America/Asuncion"});
        tempMap2.put("ANAMT", new String[]{"Asia/Anadyr"});
        tempMap2.put("ANAST", new String[]{"Asia/Anadyr"});
        tempMap2.put("ANAT", new String[]{"Asia/Anadyr"});
        tempMap2.put("ANT", new String[]{"America/Aruba", "America/Curacao"});
        tempMap2.put("AQTST", new String[]{"Asia/Aqtobe", "Asia/Aqtau"});
        tempMap2.put("AQTT", new String[]{"Asia/Aqtobe", "Asia/Aqtau"});
        tempMap2.put("ARST", new String[]{"Antarctica/Palmer", "America/Buenos_Aires", "America/Rosario", "America/Cordoba", "America/Jujuy", "America/Catamarca", "America/Mendoza"});
        tempMap2.put("ART", new String[]{"Antarctica/Palmer", "America/Buenos_Aires", "America/Rosario", "America/Cordoba", "America/Jujuy", "America/Catamarca", "America/Mendoza"});
        tempMap2.put("ASHST", new String[]{"Asia/Ashkhabad"});
        tempMap2.put("ASHT", new String[]{"Asia/Ashkhabad"});
        tempMap2.put("AST", new String[]{"Atlantic/Bermuda", "Asia/Bahrain", "Asia/Baghdad", "Asia/Kuwait", "Asia/Qatar", "Asia/Riyadh", "Asia/Aden", "America/Thule", "America/Goose_Bay", "America/Halifax", "America/Glace_Bay", "America/Pangnirtung", "America/Anguilla", "America/Antigua", "America/Barbados", "America/Dominica", "America/Santo_Domingo", "America/Grenada", "America/Guadeloupe", "America/Martinique", "America/Montserrat", "America/Puerto_Rico", "America/St_Kitts", "America/St_Lucia", "America/Miquelon", "America/St_Vincent", "America/Tortola", "America/St_Thomas", "America/Aruba", "America/Curacao", "America/Port_of_Spain"});
        tempMap2.put("AWT", new String[]{"America/Puerto_Rico"});
        tempMap2.put("AZOST", new String[]{"Atlantic/Azores"});
        tempMap2.put("AZOT", new String[]{"Atlantic/Azores"});
        tempMap2.put("AZST", new String[]{"Asia/Baku"});
        tempMap2.put("AZT", new String[]{"Asia/Baku"});
        tempMap2.put("BAKST", new String[]{"Asia/Baku"});
        tempMap2.put("BAKT", new String[]{"Asia/Baku"});
        tempMap2.put("BDT", new String[]{"Asia/Dacca", "America/Nome", "America/Adak"});
        tempMap2.put("BEAT", new String[]{"Africa/Nairobi", "Africa/Mogadishu", "Africa/Kampala"});
        tempMap2.put("BEAUT", new String[]{"Africa/Nairobi", "Africa/Dar_es_Salaam", "Africa/Kampala"});
        tempMap2.put("BMT", new String[]{"Europe/Brussels", "Europe/Chisinau", "Europe/Tiraspol", "Europe/Bucharest", "Europe/Zurich", "Asia/Baghdad", "Asia/Bangkok", "Africa/Banjul", "America/Barbados", "America/Bogota"});
        tempMap2.put("BNT", new String[]{"Asia/Brunei"});
        tempMap2.put("BORT", new String[]{"Asia/Ujung_Pandang", "Asia/Kuching"});
        tempMap2.put("BOST", new String[]{"America/La_Paz"});
        tempMap2.put("BOT", new String[]{"America/La_Paz"});
        tempMap2.put("BRST", new String[]{"America/Belem", "America/Fortaleza", "America/Araguaina", "America/Maceio", "America/Sao_Paulo"});
        tempMap2.put("BRT", new String[]{"America/Belem", "America/Fortaleza", "America/Araguaina", "America/Maceio", "America/Sao_Paulo"});
        tempMap2.put("BST", new String[]{"Europe/London", "Europe/Belfast", "Europe/Dublin", "Europe/Gibraltar", "Pacific/Pago_Pago", "Pacific/Midway", "America/Nome", "America/Adak"});
        tempMap2.put("BTT", new String[]{"Asia/Thimbu"});
        tempMap2.put("BURT", new String[]{"Asia/Dacca", "Asia/Rangoon", "Asia/Calcutta"});
        tempMap2.put("BWT", new String[]{"America/Nome", "America/Adak"});
        tempMap2.put("CANT", new String[]{"Atlantic/Canary"});
        tempMap2.put("CAST", new String[]{"Africa/Gaborone", "Africa/Khartoum"});
        tempMap2.put("CAT", new String[]{"Africa/Gaborone", "Africa/Bujumbura", "Africa/Lubumbashi", "Africa/Blantyre", "Africa/Maputo", "Africa/Windhoek", "Africa/Kigali", "Africa/Khartoum", "Africa/Lusaka", "Africa/Harare", "America/Anchorage"});
        tempMap2.put("CCT", new String[]{"Indian/Cocos"});
        tempMap2.put("CDDT", new String[]{"America/Rankin_Inlet"});
        tempMap2.put("CDT", new String[]{"Asia/Harbin", "Asia/Shanghai", "Asia/Chungking", "Asia/Urumqi", "Asia/Kashgar", "Asia/Taipei", "Asia/Macao", "America/Chicago", "America/Indianapolis", "America/Indiana/Marengo", "America/Indiana/Knox", "America/Indiana/Vevay", "America/Louisville", "America/Menominee", "America/Rainy_River", "America/Winnipeg", "America/Pangnirtung", "America/Iqaluit", "America/Rankin_Inlet", "America/Cambridge_Bay", "America/Cancun", "America/Mexico_City", "America/Chihuahua", "America/Belize", "America/Costa_Rica", "America/Havana", "America/El_Salvador", "America/Guatemala", "America/Tegucigalpa", "America/Managua"});
        tempMap2.put("CEST", new String[]{"Europe/Tirane", "Europe/Andorra", "Europe/Vienna", "Europe/Minsk", "Europe/Brussels", "Europe/Sofia", "Europe/Prague", "Europe/Copenhagen", "Europe/Tallinn", "Europe/Berlin", "Europe/Gibraltar", "Europe/Athens", "Europe/Budapest", "Europe/Rome", "Europe/Riga", "Europe/Vaduz", "Europe/Vilnius", "Europe/Luxembourg", "Europe/Malta", "Europe/Chisinau", "Europe/Tiraspol", "Europe/Monaco", "Europe/Amsterdam", "Europe/Oslo", "Europe/Warsaw", "Europe/Lisbon", "Europe/Kaliningrad", "Europe/Madrid", "Europe/Stockholm", "Europe/Zurich", "Europe/Kiev", "Europe/Uzhgorod", "Europe/Zaporozhye", "Europe/Simferopol", "Europe/Belgrade", "Africa/Algiers", "Africa/Tripoli", "Africa/Tunis", "Africa/Ceuta"});
        tempMap2.put("CET", new String[]{"Europe/Tirane", "Europe/Andorra", "Europe/Vienna", "Europe/Minsk", "Europe/Brussels", "Europe/Sofia", "Europe/Prague", "Europe/Copenhagen", "Europe/Tallinn", "Europe/Berlin", "Europe/Gibraltar", "Europe/Athens", "Europe/Budapest", "Europe/Rome", "Europe/Riga", "Europe/Vaduz", "Europe/Vilnius", "Europe/Luxembourg", "Europe/Malta", "Europe/Chisinau", "Europe/Tiraspol", "Europe/Monaco", "Europe/Amsterdam", "Europe/Oslo", "Europe/Warsaw", "Europe/Lisbon", "Europe/Kaliningrad", "Europe/Madrid", "Europe/Stockholm", "Europe/Zurich", "Europe/Kiev", "Europe/Uzhgorod", "Europe/Zaporozhye", "Europe/Simferopol", "Europe/Belgrade", "Africa/Algiers", "Africa/Tripoli", "Africa/Casablanca", "Africa/Tunis", "Africa/Ceuta"});
        tempMap2.put("CGST", new String[]{"America/Scoresbysund"});
        tempMap2.put("CGT", new String[]{"America/Scoresbysund"});
        tempMap2.put("CHDT", new String[]{"America/Belize"});
        tempMap2.put("CHUT", new String[]{"Asia/Chungking"});
        tempMap2.put("CJT", new String[]{"Asia/Tokyo"});
        tempMap2.put("CKHST", new String[]{"Pacific/Rarotonga"});
        tempMap2.put("CKT", new String[]{"Pacific/Rarotonga"});
        tempMap2.put("CLST", new String[]{"Antarctica/Palmer", "America/Santiago"});
        tempMap2.put("CLT", new String[]{"Antarctica/Palmer", "America/Santiago"});
        tempMap2.put("CMT", new String[]{"Europe/Copenhagen", "Europe/Chisinau", "Europe/Tiraspol", "America/St_Lucia", "America/Buenos_Aires", "America/Rosario", "America/Cordoba", "America/Jujuy", "America/Catamarca", "America/Mendoza", "America/Caracas"});
        tempMap2.put("COST", new String[]{"America/Bogota"});
        tempMap2.put("COT", new String[]{"America/Bogota"});
        tempMap2.put("CST", new String[]{"Asia/Harbin", "Asia/Shanghai", "Asia/Chungking", "Asia/Urumqi", "Asia/Kashgar", "Asia/Taipei", "Asia/Macao", "Asia/Jayapura", "Australia/Darwin", "Australia/Adelaide", "Australia/Broken_Hill", "America/Chicago", "America/Indianapolis", "America/Indiana/Marengo", "America/Indiana/Knox", "America/Indiana/Vevay", "America/Louisville", "America/Detroit", "America/Menominee", "America/Rainy_River", "America/Winnipeg", "America/Regina", "America/Swift_Current", "America/Pangnirtung", "America/Iqaluit", "America/Rankin_Inlet", "America/Cambridge_Bay", "America/Cancun", "America/Mexico_City", "America/Chihuahua", "America/Hermosillo", "America/Mazatlan", "America/Belize", "America/Costa_Rica", "America/Havana", "America/El_Salvador", "America/Guatemala", "America/Tegucigalpa", "America/Managua"});
        tempMap2.put("CUT", new String[]{"Europe/Zaporozhye"});
        tempMap2.put("CVST", new String[]{"Atlantic/Cape_Verde"});
        tempMap2.put("CVT", new String[]{"Atlantic/Cape_Verde"});
        tempMap2.put("CWT", new String[]{"America/Chicago", "America/Indianapolis", "America/Indiana/Marengo", "America/Indiana/Knox", "America/Indiana/Vevay", "America/Louisville", "America/Menominee"});
        tempMap2.put("CXT", new String[]{"Indian/Christmas"});
        tempMap2.put("DACT", new String[]{"Asia/Dacca"});
        tempMap2.put("DAVT", new String[]{"Antarctica/Davis"});
        tempMap2.put("DDUT", new String[]{"Antarctica/DumontDUrville"});
        tempMap2.put("DFT", new String[]{"Europe/Oslo", "Europe/Paris"});
        tempMap2.put("DMT", new String[]{"Europe/Belfast", "Europe/Dublin"});
        tempMap2.put("DUSST", new String[]{"Asia/Dushanbe"});
        tempMap2.put("DUST", new String[]{"Asia/Dushanbe"});
        tempMap2.put("EASST", new String[]{"Pacific/Easter"});
        tempMap2.put("EAST", new String[]{"Indian/Antananarivo", "Pacific/Easter"});
        tempMap2.put("EAT", new String[]{"Indian/Comoro", "Indian/Antananarivo", "Indian/Mayotte", "Africa/Djibouti", "Africa/Asmera", "Africa/Addis_Ababa", "Africa/Nairobi", "Africa/Mogadishu", "Africa/Khartoum", "Africa/Dar_es_Salaam", "Africa/Kampala"});
        tempMap2.put("ECT", new String[]{"Pacific/Galapagos", "America/Guayaquil"});
        tempMap2.put("EDDT", new String[]{"America/Iqaluit"});
        tempMap2.put("EDT", new String[]{"America/New_York", "America/Indianapolis", "America/Indiana/Marengo", "America/Indiana/Vevay", "America/Louisville", "America/Detroit", "America/Montreal", "America/Thunder_Bay", "America/Nipigon", "America/Pangnirtung", "America/Iqaluit", "America/Cancun", "America/Nassau", "America/Santo_Domingo", "America/Port-au-Prince", "America/Jamaica", "America/Grand_Turk"});
        tempMap2.put("EEMT", new String[]{"Europe/Minsk", "Europe/Chisinau", "Europe/Tiraspol", "Europe/Kaliningrad", "Europe/Moscow"});
        tempMap2.put("EEST", new String[]{"Europe/Minsk", "Europe/Sofia", "Europe/Tallinn", "Europe/Helsinki", "Europe/Athens", "Europe/Riga", "Europe/Vilnius", "Europe/Chisinau", "Europe/Tiraspol", "Europe/Warsaw", "Europe/Bucharest", "Europe/Kaliningrad", "Europe/Moscow", "Europe/Istanbul", "Europe/Kiev", "Europe/Uzhgorod", "Europe/Zaporozhye", "Asia/Nicosia", "Asia/Amman", "Asia/Beirut", "Asia/Gaza", "Asia/Damascus", "Africa/Cairo"});
        tempMap2.put("EET", new String[]{"Europe/Minsk", "Europe/Sofia", "Europe/Tallinn", "Europe/Helsinki", "Europe/Athens", "Europe/Riga", "Europe/Vilnius", "Europe/Chisinau", "Europe/Tiraspol", "Europe/Warsaw", "Europe/Bucharest", "Europe/Kaliningrad", "Europe/Moscow", "Europe/Istanbul", "Europe/Kiev", "Europe/Uzhgorod", "Europe/Zaporozhye", "Europe/Simferopol", "Asia/Nicosia", "Asia/Amman", "Asia/Beirut", "Asia/Gaza", "Asia/Damascus", "Africa/Cairo", "Africa/Tripoli"});
        tempMap2.put("EGST", new String[]{"America/Scoresbysund"});
        tempMap2.put("EGT", new String[]{"Atlantic/Jan_Mayen", "America/Scoresbysund"});
        tempMap2.put("EHDT", new String[]{"America/Santo_Domingo"});
        tempMap2.put("EST", new String[]{"Australia/Brisbane", "Australia/Lindeman", "Australia/Hobart", "Australia/Melbourne", "Australia/Sydney", "Australia/Broken_Hill", "Australia/Lord_Howe", "America/New_York", "America/Chicago", "America/Indianapolis", "America/Indiana/Marengo", "America/Indiana/Knox", "America/Indiana/Vevay", "America/Louisville", "America/Detroit", "America/Menominee", "America/Montreal", "America/Thunder_Bay", "America/Nipigon", "America/Pangnirtung", "America/Iqaluit", "America/Cancun", "America/Antigua", "America/Nassau", "America/Cayman", "America/Santo_Domingo", "America/Port-au-Prince", "America/Jamaica", "America/Managua", "America/Panama", "America/Grand_Turk"});
        tempMap2.put("EWT", new String[]{"America/New_York", "America/Indianapolis", "America/Indiana/Marengo", "America/Indiana/Vevay", "America/Louisville", "America/Detroit", "America/Jamaica"});
        tempMap2.put("FFMT", new String[]{"America/Martinique"});
        tempMap2.put("FJST", new String[]{"Pacific/Fiji"});
        tempMap2.put("FJT", new String[]{"Pacific/Fiji"});
        tempMap2.put("FKST", new String[]{"Atlantic/Stanley"});
        tempMap2.put("FKT", new String[]{"Atlantic/Stanley"});
        tempMap2.put("FMT", new String[]{"Atlantic/Madeira", "Africa/Freetown"});
        tempMap2.put("FNST", new String[]{"America/Noronha"});
        tempMap2.put("FNT", new String[]{"America/Noronha"});
        tempMap2.put("FRUST", new String[]{"Asia/Bishkek"});
        tempMap2.put("FRUT", new String[]{"Asia/Bishkek"});
        tempMap2.put("GALT", new String[]{"Pacific/Galapagos"});
        tempMap2.put("GAMT", new String[]{"Pacific/Gambier"});
        tempMap2.put("GBGT", new String[]{"America/Guyana"});
        tempMap2.put("GEST", new String[]{"Asia/Tbilisi"});
        tempMap2.put("GET", new String[]{"Asia/Tbilisi"});
        tempMap2.put("GFT", new String[]{"America/Cayenne"});
        tempMap2.put("GHST", new String[]{"Africa/Accra"});
        tempMap2.put("GILT", new String[]{"Pacific/Tarawa"});
        tempMap2.put("GMT", new String[]{"Atlantic/St_Helena", "Atlantic/Reykjavik", "Europe/London", "Europe/Belfast", "Europe/Dublin", "Europe/Gibraltar", "Africa/Porto-Novo", "Africa/Ouagadougou", "Africa/Abidjan", "Africa/Malabo", "Africa/Banjul", "Africa/Accra", "Africa/Conakry", "Africa/Bissau", "Africa/Monrovia", "Africa/Bamako", "Africa/Timbuktu", "Africa/Nouakchott", "Africa/Niamey", "Africa/Sao_Tome", "Africa/Dakar", "Africa/Freetown", "Africa/Lome"});
        tempMap2.put("GST", new String[]{"Atlantic/South_Georgia", "Asia/Bahrain", "Asia/Muscat", "Asia/Qatar", "Asia/Dubai", "Pacific/Guam"});
        tempMap2.put("GYT", new String[]{"America/Guyana"});
        tempMap2.put("HADT", new String[]{"America/Adak"});
        tempMap2.put("HART", new String[]{"Asia/Harbin"});
        tempMap2.put("HAST", new String[]{"America/Adak"});
        tempMap2.put("HAWT", new String[]{"America/Adak"});
        tempMap2.put("HDT", new String[]{"Pacific/Honolulu"});
        tempMap2.put("HKST", new String[]{"Asia/Hong_Kong"});
        tempMap2.put("HKT", new String[]{"Asia/Hong_Kong"});
        tempMap2.put("HMT", new String[]{"Atlantic/Azores", "Europe/Helsinki", "Asia/Dacca", "Asia/Calcutta", "America/Havana"});
        tempMap2.put("HOVST", new String[]{"Asia/Hovd"});
        tempMap2.put("HOVT", new String[]{"Asia/Hovd"});
        tempMap2.put("HST", new String[]{"Pacific/Johnston", "Pacific/Honolulu"});
        tempMap2.put("HWT", new String[]{"Pacific/Honolulu"});
        tempMap2.put("ICT", new String[]{"Asia/Phnom_Penh", "Asia/Vientiane", "Asia/Bangkok", "Asia/Saigon"});
        tempMap2.put("IDDT", new String[]{"Asia/Jerusalem", "Asia/Gaza"});
        tempMap2.put("IDT", new String[]{"Asia/Jerusalem", "Asia/Gaza"});
        tempMap2.put("IHST", new String[]{"Asia/Colombo"});
        tempMap2.put("IMT", new String[]{"Europe/Sofia", "Europe/Istanbul", "Asia/Irkutsk"});
        tempMap2.put("IOT", new String[]{"Indian/Chagos"});
        tempMap2.put("IRKMT", new String[]{"Asia/Irkutsk"});
        tempMap2.put("IRKST", new String[]{"Asia/Irkutsk"});
        tempMap2.put("IRKT", new String[]{"Asia/Irkutsk"});
        tempMap2.put("IRST", new String[]{"Asia/Tehran"});
        tempMap2.put("IRT", new String[]{"Asia/Tehran"});
        tempMap2.put("ISST", new String[]{"Atlantic/Reykjavik"});
        tempMap2.put("IST", new String[]{"Atlantic/Reykjavik", "Europe/Belfast", "Europe/Dublin", "Asia/Dacca", "Asia/Thimbu", "Asia/Calcutta", "Asia/Jerusalem", "Asia/Katmandu", "Asia/Karachi", "Asia/Gaza", "Asia/Colombo"});
        tempMap2.put("JAYT", new String[]{"Asia/Jayapura"});
        tempMap2.put("JMT", new String[]{"Atlantic/St_Helena", "Asia/Jerusalem"});
        tempMap2.put("JST", new String[]{"Asia/Rangoon", "Asia/Dili", "Asia/Ujung_Pandang", "Asia/Tokyo", "Asia/Kuala_Lumpur", "Asia/Kuching", "Asia/Manila", "Asia/Singapore", "Pacific/Nauru"});
        tempMap2.put("KART", new String[]{"Asia/Karachi"});
        tempMap2.put("KAST", new String[]{"Asia/Kashgar"});
        tempMap2.put("KDT", new String[]{"Asia/Seoul"});
        tempMap2.put("KGST", new String[]{"Asia/Bishkek"});
        tempMap2.put("KGT", new String[]{"Asia/Bishkek"});
        tempMap2.put("KMT", new String[]{"Europe/Vilnius", "Europe/Kiev", "America/Cayman", "America/Jamaica", "America/St_Vincent", "America/Grand_Turk"});
        tempMap2.put("KOST", new String[]{"Pacific/Kosrae"});
        tempMap2.put("KRAMT", new String[]{"Asia/Krasnoyarsk"});
        tempMap2.put("KRAST", new String[]{"Asia/Krasnoyarsk"});
        tempMap2.put("KRAT", new String[]{"Asia/Krasnoyarsk"});
        tempMap2.put("KST", new String[]{"Asia/Seoul", "Asia/Pyongyang"});
        tempMap2.put("KUYMT", new String[]{"Europe/Samara"});
        tempMap2.put("KUYST", new String[]{"Europe/Samara"});
        tempMap2.put("KUYT", new String[]{"Europe/Samara"});
        tempMap2.put("KWAT", new String[]{"Pacific/Kwajalein"});
        tempMap2.put("LHST", new String[]{"Australia/Lord_Howe"});
        tempMap2.put("LINT", new String[]{"Pacific/Kiritimati"});
        tempMap2.put("LKT", new String[]{"Asia/Colombo"});
        tempMap2.put("LPMT", new String[]{"America/La_Paz"});
        tempMap2.put("LRT", new String[]{"Africa/Monrovia"});
        tempMap2.put("LST", new String[]{"Europe/Riga"});
        tempMap2.put("M", new String[]{"Europe/Moscow"});
        tempMap2.put("MADST", new String[]{"Atlantic/Madeira"});
        tempMap2.put("MAGMT", new String[]{"Asia/Magadan"});
        tempMap2.put("MAGST", new String[]{"Asia/Magadan"});
        tempMap2.put("MAGT", new String[]{"Asia/Magadan"});
        tempMap2.put("MALT", new String[]{"Asia/Kuala_Lumpur", "Asia/Singapore"});
        tempMap2.put("MART", new String[]{"Pacific/Marquesas"});
        tempMap2.put("MAWT", new String[]{"Antarctica/Mawson"});
        tempMap2.put("MDDT", new String[]{"America/Cambridge_Bay", "America/Yellowknife", "America/Inuvik"});
        tempMap2.put("MDST", new String[]{"Europe/Moscow"});
        tempMap2.put("MDT", new String[]{"America/Denver", "America/Phoenix", "America/Boise", "America/Regina", "America/Swift_Current", "America/Edmonton", "America/Cambridge_Bay", "America/Yellowknife", "America/Inuvik", "America/Chihuahua", "America/Hermosillo", "America/Mazatlan"});
        tempMap2.put("MET", new String[]{"Europe/Tirane", "Europe/Andorra", "Europe/Vienna", "Europe/Minsk", "Europe/Brussels", "Europe/Sofia", "Europe/Prague", "Europe/Copenhagen", "Europe/Tallinn", "Europe/Berlin", "Europe/Gibraltar", "Europe/Athens", "Europe/Budapest", "Europe/Rome", "Europe/Riga", "Europe/Vaduz", "Europe/Vilnius", "Europe/Luxembourg", "Europe/Malta", "Europe/Chisinau", "Europe/Tiraspol", "Europe/Monaco", "Europe/Amsterdam", "Europe/Oslo", "Europe/Warsaw", "Europe/Lisbon", "Europe/Kaliningrad", "Europe/Madrid", "Europe/Stockholm", "Europe/Zurich", "Europe/Kiev", "Europe/Uzhgorod", "Europe/Zaporozhye", "Europe/Simferopol", "Europe/Belgrade", "Africa/Algiers", "Africa/Tripoli", "Africa/Casablanca", "Africa/Tunis", "Africa/Ceuta"});
        tempMap2.put("MHT", new String[]{"Pacific/Majuro", "Pacific/Kwajalein"});
        tempMap2.put("MMT", new String[]{"Indian/Maldives", "Europe/Minsk", "Europe/Moscow", "Asia/Rangoon", "Asia/Ujung_Pandang", "Asia/Colombo", "Pacific/Easter", "Africa/Monrovia", "America/Managua", "America/Montevideo"});
        tempMap2.put("MOST", new String[]{"Asia/Macao"});
        tempMap2.put("MOT", new String[]{"Asia/Macao"});
        tempMap2.put("MPT", new String[]{"Pacific/Saipan"});
        tempMap2.put("MSK", new String[]{"Europe/Minsk", "Europe/Tallinn", "Europe/Riga", "Europe/Vilnius", "Europe/Chisinau", "Europe/Kiev", "Europe/Uzhgorod", "Europe/Zaporozhye", "Europe/Simferopol"});
        tempMap2.put("MST", new String[]{"Europe/Moscow", "America/Denver", "America/Phoenix", "America/Boise", "America/Regina", "America/Swift_Current", "America/Edmonton", "America/Dawson_Creek", "America/Cambridge_Bay", "America/Yellowknife", "America/Inuvik", "America/Mexico_City", "America/Chihuahua", "America/Hermosillo", "America/Mazatlan", "America/Tijuana"});
        tempMap2.put("MUT", new String[]{"Indian/Mauritius"});
        tempMap2.put("MVT", new String[]{"Indian/Maldives"});
        tempMap2.put("MWT", new String[]{"America/Denver", "America/Phoenix", "America/Boise"});
        tempMap2.put("MYT", new String[]{"Asia/Kuala_Lumpur", "Asia/Kuching"});
        tempMap2.put("NCST", new String[]{"Pacific/Noumea"});
        tempMap2.put("NCT", new String[]{"Pacific/Noumea"});
        tempMap2.put("NDT", new String[]{"America/Nome", "America/Adak", "America/St_Johns", "America/Goose_Bay"});
        tempMap2.put("NEGT", new String[]{"America/Paramaribo"});
        tempMap2.put("NFT", new String[]{"Europe/Paris", "Europe/Oslo", "Pacific/Norfolk"});
        tempMap2.put("NMT", new String[]{"Pacific/Norfolk"});
        tempMap2.put("NOVMT", new String[]{"Asia/Novosibirsk"});
        tempMap2.put("NOVST", new String[]{"Asia/Novosibirsk"});
        tempMap2.put("NOVT", new String[]{"Asia/Novosibirsk"});
        tempMap2.put("NPT", new String[]{"Asia/Katmandu"});
        tempMap2.put("NRT", new String[]{"Pacific/Nauru"});
        tempMap2.put("NST", new String[]{"Europe/Amsterdam", "Pacific/Pago_Pago", "Pacific/Midway", "America/Nome", "America/Adak", "America/St_Johns", "America/Goose_Bay"});
        tempMap2.put("NUT", new String[]{"Pacific/Niue"});
        tempMap2.put("NWT", new String[]{"America/Nome", "America/Adak"});
        tempMap2.put("NZDT", new String[]{"Antarctica/McMurdo"});
        tempMap2.put("NZHDT", new String[]{"Pacific/Auckland"});
        tempMap2.put("NZST", new String[]{"Antarctica/McMurdo", "Pacific/Auckland"});
        tempMap2.put("OMSMT", new String[]{"Asia/Omsk"});
        tempMap2.put("OMSST", new String[]{"Asia/Omsk"});
        tempMap2.put("OMST", new String[]{"Asia/Omsk"});
        tempMap2.put("PDDT", new String[]{"America/Inuvik", "America/Whitehorse", "America/Dawson"});
        tempMap2.put("PDT", new String[]{"America/Los_Angeles", "America/Juneau", "America/Boise", "America/Vancouver", "America/Dawson_Creek", "America/Inuvik", "America/Whitehorse", "America/Dawson", "America/Tijuana"});
        tempMap2.put("PEST", new String[]{"America/Lima"});
        tempMap2.put("PET", new String[]{"America/Lima"});
        tempMap2.put("PETMT", new String[]{"Asia/Kamchatka"});
        tempMap2.put("PETST", new String[]{"Asia/Kamchatka"});
        tempMap2.put("PETT", new String[]{"Asia/Kamchatka"});
        tempMap2.put("PGT", new String[]{"Pacific/Port_Moresby"});
        tempMap2.put("PHOT", new String[]{"Pacific/Enderbury"});
        tempMap2.put("PHST", new String[]{"Asia/Manila"});
        tempMap2.put("PHT", new String[]{"Asia/Manila"});
        tempMap2.put("PKT", new String[]{"Asia/Karachi"});
        tempMap2.put("PMDT", new String[]{"America/Miquelon"});
        tempMap2.put("PMMT", new String[]{"Pacific/Port_Moresby"});
        tempMap2.put("PMST", new String[]{"America/Miquelon"});
        tempMap2.put("PMT", new String[]{"Antarctica/DumontDUrville", "Europe/Prague", "Europe/Paris", "Europe/Monaco", "Africa/Algiers", "Africa/Tunis", "America/Panama", "America/Paramaribo"});
        tempMap2.put("PNT", new String[]{"Pacific/Pitcairn"});
        tempMap2.put("PONT", new String[]{"Pacific/Ponape"});
        tempMap2.put("PPMT", new String[]{"America/Port-au-Prince"});
        tempMap2.put("PST", new String[]{"Pacific/Pitcairn", "America/Los_Angeles", "America/Juneau", "America/Boise", "America/Vancouver", "America/Dawson_Creek", "America/Inuvik", "America/Whitehorse", "America/Dawson", "America/Hermosillo", "America/Mazatlan", "America/Tijuana"});
        tempMap2.put("PWT", new String[]{"Pacific/Palau", "America/Los_Angeles", "America/Juneau", "America/Boise", "America/Tijuana"});
        tempMap2.put("PYST", new String[]{"America/Asuncion"});
        tempMap2.put("PYT", new String[]{"America/Asuncion"});
        tempMap2.put("QMT", new String[]{"America/Guayaquil"});
        tempMap2.put("RET", new String[]{"Indian/Reunion"});
        tempMap2.put("RMT", new String[]{"Atlantic/Reykjavik", "Europe/Rome", "Europe/Riga", "Asia/Rangoon"});
        tempMap2.put("S", new String[]{"Europe/Moscow"});
        tempMap2.put("SAMMT", new String[]{"Europe/Samara"});
        tempMap2.put("SAMST", new String[]{"Europe/Samara", "Asia/Samarkand"});
        tempMap2.put("SAMT", new String[]{"Europe/Samara", "Asia/Samarkand", "Pacific/Pago_Pago", "Pacific/Apia"});
        tempMap2.put("SAST", new String[]{"Africa/Maseru", "Africa/Windhoek", "Africa/Johannesburg", "Africa/Mbabane"});
        tempMap2.put("SBT", new String[]{"Pacific/Guadalcanal"});
        tempMap2.put("SCT", new String[]{"Indian/Mahe"});
        tempMap2.put("SDMT", new String[]{"America/Santo_Domingo"});
        tempMap2.put("SGT", new String[]{"Asia/Singapore"});
        tempMap2.put("SHEST", new String[]{"Asia/Aqtau"});
        tempMap2.put("SHET", new String[]{"Asia/Aqtau"});
        tempMap2.put("SJMT", new String[]{"America/Costa_Rica"});
        tempMap2.put("SLST", new String[]{"Africa/Freetown"});
        tempMap2.put("SMT", new String[]{"Atlantic/Stanley", "Europe/Stockholm", "Europe/Simferopol", "Asia/Phnom_Penh", "Asia/Vientiane", "Asia/Kuala_Lumpur", "Asia/Singapore", "Asia/Saigon", "America/Santiago"});
        tempMap2.put("SRT", new String[]{"America/Paramaribo"});
        tempMap2.put("SST", new String[]{"Pacific/Pago_Pago", "Pacific/Midway"});
        tempMap2.put("SVEMT", new String[]{"Asia/Yekaterinburg"});
        tempMap2.put("SVEST", new String[]{"Asia/Yekaterinburg"});
        tempMap2.put("SVET", new String[]{"Asia/Yekaterinburg"});
        tempMap2.put("SWAT", new String[]{"Africa/Windhoek"});
        tempMap2.put("SYOT", new String[]{"Antarctica/Syowa"});
        tempMap2.put("TAHT", new String[]{"Pacific/Tahiti"});
        tempMap2.put("TASST", new String[]{"Asia/Samarkand", "Asia/Tashkent"});
        tempMap2.put("TAST", new String[]{"Asia/Samarkand", "Asia/Tashkent"});
        tempMap2.put("TBIST", new String[]{"Asia/Tbilisi"});
        tempMap2.put("TBIT", new String[]{"Asia/Tbilisi"});
        tempMap2.put("TBMT", new String[]{"Asia/Tbilisi"});
        tempMap2.put("TFT", new String[]{"Indian/Kerguelen"});
        tempMap2.put("TJT", new String[]{"Asia/Dushanbe"});
        tempMap2.put("TKT", new String[]{"Pacific/Fakaofo"});
        tempMap2.put("TMST", new String[]{"Asia/Ashkhabad"});
        tempMap2.put("TMT", new String[]{"Europe/Tallinn", "Asia/Tehran", "Asia/Ashkhabad"});
        tempMap2.put("TOST", new String[]{"Pacific/Tongatapu"});
        tempMap2.put("TOT", new String[]{"Pacific/Tongatapu"});
        tempMap2.put("TPT", new String[]{"Asia/Dili"});
        tempMap2.put("TRST", new String[]{"Europe/Istanbul"});
        tempMap2.put("TRT", new String[]{"Europe/Istanbul"});
        tempMap2.put("TRUT", new String[]{"Pacific/Truk"});
        tempMap2.put("TVT", new String[]{"Pacific/Funafuti"});
        tempMap2.put("ULAST", new String[]{"Asia/Ulaanbaatar"});
        tempMap2.put("ULAT", new String[]{"Asia/Ulaanbaatar"});
        tempMap2.put("URUT", new String[]{"Asia/Urumqi"});
        tempMap2.put("UYHST", new String[]{"America/Montevideo"});
        tempMap2.put("UYT", new String[]{"America/Montevideo"});
        tempMap2.put("UZST", new String[]{"Asia/Samarkand", "Asia/Tashkent"});
        tempMap2.put("UZT", new String[]{"Asia/Samarkand", "Asia/Tashkent"});
        tempMap2.put("VET", new String[]{"America/Caracas"});
        tempMap2.put("VLAMT", new String[]{"Asia/Vladivostok"});
        tempMap2.put("VLAST", new String[]{"Asia/Vladivostok"});
        tempMap2.put("VLAT", new String[]{"Asia/Vladivostok"});
        tempMap2.put("VUST", new String[]{"Pacific/Efate"});
        tempMap2.put("VUT", new String[]{"Pacific/Efate"});
        tempMap2.put("WAKT", new String[]{"Pacific/Wake"});
        tempMap2.put("WARST", new String[]{"America/Jujuy", "America/Mendoza"});
        tempMap2.put("WART", new String[]{"America/Jujuy", "America/Mendoza"});
        tempMap2.put("WAST", new String[]{"Africa/Ndjamena", "Africa/Windhoek"});
        tempMap2.put("WAT", new String[]{"Africa/Luanda", "Africa/Porto-Novo", "Africa/Douala", "Africa/Bangui", "Africa/Ndjamena", "Africa/Kinshasa", "Africa/Brazzaville", "Africa/Malabo", "Africa/Libreville", "Africa/Banjul", "Africa/Conakry", "Africa/Bissau", "Africa/Bamako", "Africa/Nouakchott", "Africa/El_Aaiun", "Africa/Windhoek", "Africa/Niamey", "Africa/Lagos", "Africa/Dakar", "Africa/Freetown"});
        tempMap2.put("WEST", new String[]{"Atlantic/Faeroe", "Atlantic/Azores", "Atlantic/Madeira", "Atlantic/Canary", "Europe/Brussels", "Europe/Luxembourg", "Europe/Monaco", "Europe/Lisbon", "Europe/Madrid", "Africa/Algiers", "Africa/Casablanca", "Africa/Ceuta"});
        tempMap2.put("WET", new String[]{"Atlantic/Faeroe", "Atlantic/Azores", "Atlantic/Madeira", "Atlantic/Canary", "Europe/Andorra", "Europe/Brussels", "Europe/Luxembourg", "Europe/Monaco", "Europe/Lisbon", "Europe/Madrid", "Africa/Algiers", "Africa/Casablanca", "Africa/El_Aaiun", "Africa/Ceuta"});
        tempMap2.put("WFT", new String[]{"Pacific/Wallis"});
        tempMap2.put("WGST", new String[]{"America/Godthab"});
        tempMap2.put("WGT", new String[]{"America/Godthab"});
        tempMap2.put("WMT", new String[]{"Europe/Vilnius", "Europe/Warsaw"});
        tempMap2.put("WST", new String[]{"Antarctica/Casey", "Pacific/Apia", "Australia/Perth"});
        tempMap2.put("YAKMT", new String[]{"Asia/Yakutsk"});
        tempMap2.put("YAKST", new String[]{"Asia/Yakutsk"});
        tempMap2.put("YAKT", new String[]{"Asia/Yakutsk"});
        tempMap2.put("YAPT", new String[]{"Pacific/Yap"});
        tempMap2.put("YDDT", new String[]{"America/Whitehorse", "America/Dawson"});
        tempMap2.put("YDT", new String[]{"America/Yakutat", "America/Whitehorse", "America/Dawson"});
        tempMap2.put("YEKMT", new String[]{"Asia/Yekaterinburg"});
        tempMap2.put("YEKST", new String[]{"Asia/Yekaterinburg"});
        tempMap2.put("YEKT", new String[]{"Asia/Yekaterinburg"});
        tempMap2.put("YERST", new String[]{"Asia/Yerevan"});
        tempMap2.put("YERT", new String[]{"Asia/Yerevan"});
        tempMap2.put("YST", new String[]{"America/Yakutat", "America/Whitehorse", "America/Dawson"});
        tempMap2.put("YWT", new String[]{"America/Yakutat"});
        ABBREVIATED_TIMEZONES = Collections.unmodifiableMap(tempMap2);
    }

    public static Time changeTimezone(ConnectionImpl conn, Calendar sessionCalendar, Calendar targetCalendar, Time t, TimeZone fromTz, TimeZone toTz, boolean rollForward) {
        long toTime;
        if (conn != null) {
            if (conn.getUseTimezone() && !conn.getNoTimezoneConversionForTimeType()) {
                Calendar fromCal = Calendar.getInstance(fromTz);
                fromCal.setTime(t);
                int fromOffset = fromCal.get(15) + fromCal.get(16);
                Calendar toCal = Calendar.getInstance(toTz);
                toCal.setTime(t);
                int toOffset = toCal.get(15) + toCal.get(16);
                int offsetDiff = fromOffset - toOffset;
                long toTime2 = toCal.getTime().getTime();
                if (rollForward || (conn.isServerTzUTC() && !conn.isClientTzUTC())) {
                    toTime = toTime2 + offsetDiff;
                } else {
                    toTime = toTime2 - offsetDiff;
                }
                Time changedTime = new Time(toTime);
                return changedTime;
            }
            if (conn.getUseJDBCCompliantTimezoneShift() && targetCalendar != null) {
                Time adjustedTime = new Time(jdbcCompliantZoneShift(sessionCalendar, targetCalendar, t));
                return adjustedTime;
            }
        }
        return t;
    }

    public static Timestamp changeTimezone(ConnectionImpl conn, Calendar sessionCalendar, Calendar targetCalendar, Timestamp tstamp, TimeZone fromTz, TimeZone toTz, boolean rollForward) {
        long toTime;
        if (conn != null) {
            if (conn.getUseTimezone()) {
                Calendar fromCal = Calendar.getInstance(fromTz);
                fromCal.setTime(tstamp);
                int fromOffset = fromCal.get(15) + fromCal.get(16);
                Calendar toCal = Calendar.getInstance(toTz);
                toCal.setTime(tstamp);
                int toOffset = toCal.get(15) + toCal.get(16);
                int offsetDiff = fromOffset - toOffset;
                long toTime2 = toCal.getTime().getTime();
                if (rollForward || (conn.isServerTzUTC() && !conn.isClientTzUTC())) {
                    toTime = toTime2 + offsetDiff;
                } else {
                    toTime = toTime2 - offsetDiff;
                }
                Timestamp changedTimestamp = new Timestamp(toTime);
                return changedTimestamp;
            }
            if (conn.getUseJDBCCompliantTimezoneShift() && targetCalendar != null) {
                Timestamp adjustedTimestamp = new Timestamp(jdbcCompliantZoneShift(sessionCalendar, targetCalendar, tstamp));
                adjustedTimestamp.setNanos(tstamp.getNanos());
                return adjustedTimestamp;
            }
        }
        return tstamp;
    }

    private static long jdbcCompliantZoneShift(Calendar sessionCalendar, Calendar targetCalendar, Date dt) {
        if (sessionCalendar == null) {
            sessionCalendar = new GregorianCalendar();
        }
        Date origCalDate = targetCalendar.getTime();
        Date origSessionDate = sessionCalendar.getTime();
        try {
            sessionCalendar.setTime(dt);
            targetCalendar.set(1, sessionCalendar.get(1));
            targetCalendar.set(2, sessionCalendar.get(2));
            targetCalendar.set(5, sessionCalendar.get(5));
            targetCalendar.set(11, sessionCalendar.get(11));
            targetCalendar.set(12, sessionCalendar.get(12));
            targetCalendar.set(13, sessionCalendar.get(13));
            targetCalendar.set(14, sessionCalendar.get(14));
            long time = targetCalendar.getTime().getTime();
            sessionCalendar.setTime(origSessionDate);
            targetCalendar.setTime(origCalDate);
            return time;
        } catch (Throwable th) {
            sessionCalendar.setTime(origSessionDate);
            targetCalendar.setTime(origCalDate);
            throw th;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static final java.sql.Date fastDateCreate(boolean useGmtConversion, Calendar gmtCalIfNeeded, Calendar cal, int year, int month, int day) {
        long dateAsMillis;
        Calendar dateCal = cal;
        if (useGmtConversion) {
            if (gmtCalIfNeeded == null) {
                gmtCalIfNeeded = Calendar.getInstance(TimeZone.getTimeZone("GMT"));
            }
            gmtCalIfNeeded.clear();
            dateCal = gmtCalIfNeeded;
        }
        dateCal.clear();
        dateCal.set(year, month - 1, day, 0, 0, 0);
        try {
            dateAsMillis = dateCal.getTimeInMillis();
        } catch (IllegalAccessError e) {
            dateAsMillis = dateCal.getTime().getTime();
        }
        return new java.sql.Date(dateAsMillis);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static final Time fastTimeCreate(Calendar cal, int hour, int minute, int second) throws SQLException {
        long timeAsMillis;
        if (hour < 0 || hour > 23) {
            throw SQLError.createSQLException(new StringBuffer().append("Illegal hour value '").append(hour).append("' for java.sql.Time type in value '").append(timeFormattedString(hour, minute, second)).append(".").toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        if (minute < 0 || minute > 59) {
            throw SQLError.createSQLException(new StringBuffer().append("Illegal minute value '").append(minute).append("'").append("' for java.sql.Time type in value '").append(timeFormattedString(hour, minute, second)).append(".").toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        if (second < 0 || second > 59) {
            throw SQLError.createSQLException(new StringBuffer().append("Illegal minute value '").append(second).append("'").append("' for java.sql.Time type in value '").append(timeFormattedString(hour, minute, second)).append(".").toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        cal.clear();
        cal.set(1970, 0, 1, hour, minute, second);
        try {
            timeAsMillis = cal.getTimeInMillis();
        } catch (IllegalAccessError e) {
            timeAsMillis = cal.getTime().getTime();
        }
        return new Time(timeAsMillis);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static final Timestamp fastTimestampCreate(boolean useGmtConversion, Calendar gmtCalIfNeeded, Calendar cal, int year, int month, int day, int hour, int minute, int seconds, int secondsPart) {
        long tsAsMillis;
        cal.clear();
        cal.set(year, month - 1, day, hour, minute, seconds);
        int offsetDiff = 0;
        if (useGmtConversion) {
            int fromOffset = cal.get(15) + cal.get(16);
            if (gmtCalIfNeeded == null) {
                gmtCalIfNeeded = Calendar.getInstance(TimeZone.getTimeZone("GMT"));
            }
            gmtCalIfNeeded.clear();
            gmtCalIfNeeded.setTimeInMillis(cal.getTimeInMillis());
            int toOffset = gmtCalIfNeeded.get(15) + gmtCalIfNeeded.get(16);
            offsetDiff = fromOffset - toOffset;
        }
        try {
            tsAsMillis = cal.getTimeInMillis();
        } catch (IllegalAccessError e) {
            tsAsMillis = cal.getTime().getTime();
        }
        Timestamp ts = new Timestamp(tsAsMillis + offsetDiff);
        ts.setNanos(secondsPart);
        return ts;
    }

    public static String getCanoncialTimezone(String timezoneStr) {
        String[] abbreviatedTimezone;
        if (timezoneStr == null) {
            return null;
        }
        String timezoneStr2 = timezoneStr.trim();
        int daylightIndex = StringUtils.indexOfIgnoreCase(timezoneStr2, "DAYLIGHT");
        if (daylightIndex != -1) {
            StringBuffer timezoneBuf = new StringBuffer();
            timezoneBuf.append(timezoneStr2.substring(0, daylightIndex));
            timezoneBuf.append("Standard");
            timezoneBuf.append(timezoneStr2.substring(daylightIndex + "DAYLIGHT".length(), timezoneStr2.length()));
            timezoneStr2 = timezoneBuf.toString();
        }
        String canonicalTz = (String) TIMEZONE_MAPPINGS.get(timezoneStr2);
        if (canonicalTz == null && (abbreviatedTimezone = (String[]) ABBREVIATED_TIMEZONES.get(timezoneStr2)) != null) {
            if (abbreviatedTimezone.length == 1) {
                canonicalTz = abbreviatedTimezone[0];
            } else {
                StringBuffer errorMsg = new StringBuffer("The server timezone value '");
                errorMsg.append(timezoneStr2);
                errorMsg.append("' represents more than one timezone. You must ");
                errorMsg.append("configure either the server or client to use a ");
                errorMsg.append("more specifc timezone value if you want to enable ");
                errorMsg.append("timezone support. The timezones that '");
                errorMsg.append(timezoneStr2);
                errorMsg.append("' maps to are: ");
                errorMsg.append(abbreviatedTimezone[0]);
                for (int i = 1; i < abbreviatedTimezone.length; i++) {
                    errorMsg.append(", ");
                    errorMsg.append(abbreviatedTimezone[i]);
                }
                throw new IllegalArgumentException(errorMsg.toString());
            }
        }
        return canonicalTz;
    }

    private static String timeFormattedString(int hours, int minutes, int seconds) {
        StringBuffer buf = new StringBuffer(8);
        if (hours < 10) {
            buf.append("0");
        }
        buf.append(hours);
        buf.append(":");
        if (minutes < 10) {
            buf.append("0");
        }
        buf.append(minutes);
        buf.append(":");
        if (seconds < 10) {
            buf.append("0");
        }
        buf.append(seconds);
        return buf.toString();
    }
}
